@@ -38,6 +38,8 @@ class FeedForwardWithCompression(nn.Module):
             self.non_linearity = nn.LeakyReLU()
         elif non_linearity == "tanh":
             self.non_linearity = nn.Tanh()
+        else:
+            self.non_linearity = nn.ReLU()
         if hidden_size is None or hidden_size == 0:
             hidden_size = input_size * 4
         if dropout is not None and dropout != 0:
@@ -83,12 +85,25 @@ class FeedForwardWithCompressionState(nn.Module):
         self.net1 = nn.Linear(input_size, hidden_size, device=device)
         if non_linearity == "relu":
             self.net2 = nn.ReLU()
+            self.gateact = nn.Identity()
         elif non_linearity == "leaky_relu":
             self.net2 = nn.LeakyReLU()
+            self.gateact = nn.Identity()
         elif non_linearity == "tanh":
             self.net2 = nn.Tanh()
+            self.gateact = nn.Identity()
+        elif non_linearity == "relurelu":
+            self.net2 = nn.ReLU()
+            self.gateact = nn.ReLU()
+        elif non_linearity == "leaky_relurelu":
+            self.net2 = nn.LeakyReLU()
+            self.gateact = nn.LeakyReLU()
+        elif non_linearity == "tanhhanh":
+            self.net2 = nn.Tanh()
+            self.gateact = nn.Tanh()
         else:
             self.net2 = nn.ReLU()
+            self.gateact = nn.Identity()
         if hidden_size is None or hidden_size == 0:
             hidden_size = input_size * 4
         self.net3 = nn.Linear(hidden_size, input_size, device=device)
@@ -97,16 +112,15 @@ class FeedForwardWithCompressionState(nn.Module):
         else:
             self.net4 = nn.Identity()
         self.gatenet = nn.Linear(hidden_size, hidden_size, device=device)
-        # self.gateact = nn.Tanh()
         self.state_zero = torch.zeros((1, input_size, hidden_size), device=device)
 
     def forward(self, x, state):
         x = self.net1(x)
-        state = self.gatenet(self.state_zero[:, -x.shape[1] :, :] + state))
-        # state = self.gateact(state)
+        state = self.gatenet(self.state_zero[:, -x.shape[1] :, :] + state)
+        state = self.gateact(state)
         x = x + state
-        state = x
         x = self.net2(x)
+        state = x
         x = self.net3(x)
         x = self.net4(x)
         return x, state
